lace
===========

A mesh class loaded with useful geometric and analysis functionality.



Development
-----------

```sh
pip install -r requirements_dev.txt
pip install -e .
rake test
rake lint
```


Contribute
----------

- Issue Tracker: github.com/bodylabs/example/issues
- Source Code: github.com/bodylabs/example

Pull requests welcome!


Support
-------

If you are having issues, please let us know.


License
-------

The project is licensed under the two-clause BSD license.

This project uses the RPly library to read and write PLY files, by Diego Nehab,
IMPA, distributed under the MIT License.
 * http://www.impa.br/~diego/software/rply
